import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { getConfig } from '../../config.js';
import { checkAnalyticsGdprIsAccepted, getGdprPrivacyValue } from '../../tcf.js';

/* Static anonymousId for users that has not accepted consents */
var SEGMENT_ID_USER_WITHOUT_CONSENTS = 'anonymous_user';

/**
 * Get user traits from global analytics object and put in the object
 * @param {string} gdprPrivacyValue Determine if we have user consents
 * @returns {object} User traits with to add
 */
var getUserTraits = function getUserTraits(gdprPrivacyValue) {
  var isUserTraitsEnabled = getConfig('isUserTraitsEnabled');

  // If user has not accepted GDPR then we should use a static anonymousId
  if (!checkAnalyticsGdprIsAccepted(gdprPrivacyValue)) {
    window.analytics.reset();
    window.analytics.setAnonymousId(SEGMENT_ID_USER_WITHOUT_CONSENTS);
    return {
      anonymousId: SEGMENT_ID_USER_WITHOUT_CONSENTS
    };
  }

  // If we have user consents, then create the user using anonymousId cookie
  var user = window.analytics.user();
  if (user.anonymousId() === SEGMENT_ID_USER_WITHOUT_CONSENTS) {
    window.analytics.reset();
  }
  var userId = user.id();
  var userTraits = _extends({
    anonymousId: user.anonymousId()
  }, isUserTraitsEnabled && user.traits());
  if (userId) userTraits.userId = userId;
  return userTraits;
};
export var userTraits = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var payload, next, gdprPrivacyValue, userTraits;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          payload = _ref.payload, next = _ref.next;
          _context.next = 3;
          return getGdprPrivacyValue();
        case 3:
          gdprPrivacyValue = _context.sent;
          try {
            userTraits = getUserTraits(gdprPrivacyValue);
          } catch (error) {
            console.error(error); // eslint-disable-line
          }

          payload.obj.context = _extends({}, payload.obj.context, {
            traits: _extends({}, payload.obj.context.traits, userTraits)
          });
          next(payload);
        case 7:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function userTraits(_x) {
    return _ref2.apply(this, arguments);
  };
}();